# PyDAOE: Design and Analysis of Experiments

A collection of utilities for the analysis of experiments.

Based on the book [Design and Analysis of Experiments](https://www.wiley.com/en-us/Design+and+Analysis+of+Experiments%2C+10th+Edition-p-9781119492443) by Douglas C. Montgomery,
which is covered by the [Design of Experiments Specialization](https://www.coursera.org/specializations/design-experiments) on Coursera, taught by Prof. Montgomery himself.

Note that you can freely attend all the lectures as an auditor, and each "week" of lecture covers 
exactly one chapter of the book (12 in total, divised into 4 courses).

You can also browse a summary of the DoE concepts as [notes of the STAT 503 course at Penn State University](https://online.stat.psu.edu/stat503/home).

After downloading and installing the package as:
```
git clone https://github.com/danieleongari/pyDAOE.git
cd pyDAOE
pip install -e .
```
you can find the examples and exercises inspired from the book in the `tests` folder.
The reference version of the book uses imperial units, and specifically the 9th edition of the book, 
which is also used as a reference in the Coursera specialization.